# coding: utf-8

from urllib import urlencode

import six

from novaclient import base

from tionix_client.journal.constants import ActionStatus


class JournalResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_journal'
    _version = None


class JournalManager(base.ManagerWithFind):
    resource_class = JournalResource
    alias = 'tnx-journal'

    # noinspection PyIncorrectDocstring
    # pylint:disable=too-many-arguments
    def create(self, object_id, object_type, action, success=True,
               message=None, user_id=None, user_name=None, request_id=None,
               parent_request_id=None):

        status = ActionStatus.SUCCESS if success else ActionStatus.FAILURE
        journal = {
            'object_id': object_id,
            'object_type': object_type,
            'action': action,
            'status': status,
        }
        if request_id:
            journal['request_id'] = request_id

        if parent_request_id:
            journal['parent_request_id'] = parent_request_id

        if message:
            journal['message'] = message

        if user_id:
            journal['user_id'] = user_id

        if user_name:
            journal['user_name'] = user_name

        return self._create('/' + self.alias, {'journal': journal}, 'journal')

    # pylint: disable=arguments-differ
    def list(self, user_id=None, object_type=None, object_id=None, limit=None,
             offset=None, search_opts=None):

        qparams = {}

        if search_opts is None:
            search_opts = {}

        for opt, val in six.iteritems(search_opts):
            if val:
                if isinstance(val, six.text_type):
                    val = val.encode('utf-8')
                qparams[opt] = val

        if user_id:
            qparams['user_id'] = user_id
        if object_id:
            qparams['object_ids'] = object_id
        if object_type:
            qparams['object_type'] = object_type
        if limit:
            qparams['limit'] = limit
        if offset:
            qparams['offset'] = offset

        return self._list(
            '/{0}{1}'.format(
                self.alias,
                '?{0}'.format(urlencode(qparams, doseq=True))), 'journal')


class JournalClientExtension(object):
    name = 'tnx_journal'
    manager_class = JournalManager
