# coding: utf-8

import functools

from datetime import datetime, timedelta

import logging

from webob.exc import HTTPForbidden

from tionix_client.os_clients.nova_client import nova_client


logger = logging.getLogger(__name__)


def get_timestamp_filter(hours=1):
    timestamp_from = (datetime.utcnow() - timedelta(hours=hours)).isoformat()
    return dict(
        field='timestamp',
        op='ge',
        value=timestamp_from,
    )


def tionix_admin_guard(func):
    """
    Decorator for check admin permissions.
    """
    @functools.wraps(func)
    def wrapped_f(*args, **kwargs):
        msg = 'Permission denied.'
        req = kwargs.get('req')
        context = req.environ['nova.context']
        if not context.is_admin:
            raise HTTPForbidden(explanation=msg)

        return func(*args, **kwargs)

    return wrapped_f


def get_instances_by_project(request, project_id, search_opts=None):
    search_opts = search_opts or {}
    instances = []
    context = request.environ['nova.context']
    if context.is_admin:
        search_opts['all_tenants'] = True
        search_opts['project_id'] = project_id
    try:
        nova_cl = nova_client(req=request)
        instances = nova_cl.tnx_servers.list(search_opts=search_opts)
        if context.is_admin:
            search_opts.update({'deleted': True})
            instances += nova_cl.tnx_servers.list(search_opts=search_opts)
    except Exception as err:
        logger.error(unicode(err))
    return [instance.id for instance in instances]
