# coding: utf-8

# pylint:disable=import-error, relative-import
from six.moves.urllib.parse import urlencode

from novaclient import base


class BackupSystemsResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_backup_systems'
    _version = None


class BackupSystemsManager(base.ManagerWithFind):

    resource_class = BackupSystemsResource
    alias = 'tnx-backup-systems'
    collection_name = 'backup_systems'
    member_name = 'backup_system'
    member_alias = 'backup_system'

    def get(self, identifier):
        return self._get(
            '/{0}/{1}'.format(self.alias, base.getid(identifier)),
            self.member_name)

    # pylint: disable=arguments-differ
    def list(self, domain_id=None, limit=None, offset=None):
        qparams = {}

        if domain_id:
            qparams['domain_id'] = domain_id
        if limit:
            qparams['limit'] = limit
        if offset:
            qparams['offset'] = offset

        return self._list('/{0}{1}'.format(self.alias,
                                           '?{0}'.format(urlencode(qparams))),
                          self.collection_name)

    def create(self, domain_id, **kwargs):
        """
        POST method to create backup system
        """
        body = {"domain_id": domain_id}
        if kwargs:
            body.update(**kwargs)
        return self._create(
            '/{0}'.format(self.alias),
            {self.member_alias: body},
            self.member_name)

    def update(self, identifier, **kwargs):
        """
        POST method to update backup system
        """

        return self._update(
            '/{0}/{1}'.format(self.alias, identifier),
            {self.member_alias: kwargs},
            self.member_name)

    def delete(self, identifier):
        self._delete('/{0}/{1}'.format(self.alias, base.getid(identifier)))

    def get_system_params(self, domain_id=None, backup_system=None):

        qparams = {}

        if domain_id:
            qparams['domain_id'] = domain_id
        if backup_system is not None:
            qparams['backup_system'] = backup_system

        url = '/{0}/{1}{2}'.format(self.alias,
                                   'get_system_params',
                                   '?{0}'.format(urlencode(qparams)))
        _resp, body = self.api.client.get(url)
        return body

    def get_director_name(self, domain_id=None, backup_system=None):

        qparams = {}

        if domain_id:
            qparams['domain_id'] = domain_id
        if backup_system is not None:
            qparams['backup_system'] = backup_system

        url = '/{0}/{1}{2}'.format(self.alias,
                                   'get_director_name',
                                   '?{0}'.format(urlencode(qparams)))
        _resp, body = self.api.client.get(url)
        return body


class BackupSystemsClientExtension(object):
    name = 'tnx_backup_systems'
    manager_class = BackupSystemsManager
