# coding: utf-8

from urllib import urlencode
import six
from novaclient import base


class BackupTemplatesResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_backup_templates'
    _version = None


class BackupTemplatesManager(base.ManagerWithFind):
    resource_class = BackupTemplatesResource
    alias = 'tnx-backup-templates'
    member_name = 'backup-template'
    collection_name = 'backup-templates'

    # noinspection PyIncorrectDocstring
    def create(self, **kwargs):
        """
        Create Backup Template record.
        :param domain_id: domain id
        :param name: name
        :param description: description
        :param level: level
        :param job_defs: job defs
        :param file_set: file set
        :param schedule: schedule
        """

        allowed_params = {
            'domain_id', 'name', 'description', 'level', 'job_defs',
            'file_set', 'schedule'
        }
        body = {
            self.member_name: {k: v for k, v in kwargs.items()
                               if v is not None and k in allowed_params}
        }

        return self._create('/' + self.alias, body, self.member_name)

    # pylint: disable=arguments-differ
    def list(self, limit=None, offset=None, search_opts=None):

        qparams = {}
        if search_opts is None:
            search_opts = {}

        for opt, val in six.iteritems(search_opts):
            if val:
                if isinstance(val, six.text_type):
                    val = val.encode('utf-8')
                qparams[opt] = val

        if limit:
            qparams['limit'] = limit
        if offset:
            qparams['offset'] = offset

        return self._list(
            '/{0}{1}'.format(
                self.alias,
                '?{0}'.format(urlencode(qparams, doseq=True))),
            self.collection_name)

    def delete(self, identifier):
        self._delete('/{0}/{1}'.format(self.alias, base.getid(identifier)))


class BackupTemplatesClientExtension(object):
    name = 'tnx_backup_templates'
    manager_class = BackupTemplatesManager
