# coding: utf-8
"""
Script for configuration files initialization after module installation.
"""

import os
import shutil

from tionix_client.settings import BASE_DIR
from tionix_client.helpers.i18 import ugettext as _


CONF_DIR = os.path.join(BASE_DIR, 'conf')


class ConfigureException(Exception):
    pass


def process_dir(conf_path, dest_path='/'):
    for root, dirs, files in os.walk(conf_path):
        rel_root = os.path.relpath(root, conf_path)
        for d in dirs:
            try:
                os.makedirs(os.path.join(dest_path, rel_root, d))
            except OSError:
                pass

        for f in files:
            try:
                shutil.copy(os.path.join(root, f),
                            os.path.join(dest_path, rel_root, f))
            except IOError:
                raise ConfigureException(_(
                    u'Unable to copy configuration file: {0}').format(f))


def configure(verbose=False):
    try:
        process_dir(CONF_DIR)
    except ConfigureException as err:
        result = os.EX_SOFTWARE, err.message
    except Exception as ex:
        if verbose:
            msg = _(u'Error while configuring module: {0}').format(unicode(ex))
        else:
            msg = _(u'Unknown error. Please contact your administrator.')
        result = os.EX_SOFTWARE, msg
    else:
        result = os.EX_OK, u''

    return result
