from collections import namedtuple

from kombu import Queue, Exchange
from kombu.mixins import ConsumerMixin


ServiceConfig = namedtuple(
    'ServiceConfig', [
        'vhost', 'exchange', 'topic', 'event_prefix', 'skip_events', 'parser'])


class BaseQueueWorker(ConsumerMixin):

    QUEUE_PREFIX = ''

    def __init__(self, connection, conf):
        self.connection = connection
        self.conf = conf

    def _on_message(self, body, message):
        pass

    def handle_message(self, body, message):
        self._on_message(body, message)
        message.ack()

    # noinspection PyPep8Naming
    def get_consumers(self, Consumer, channel):
        queue = Queue(
            name='{0}.{1}.events'.format(
                self.QUEUE_PREFIX, self.conf.exchange),
            exchange=Exchange(
                name=self.conf.exchange,
                type='topic',
                durable=False),
            routing_key='{0}.info'.format(self.conf.topic),
            durable=False)
        return [
            Consumer(queue, callbacks=[self.handle_message], accept=['json']),
        ]
