# coding: utf-8

import os

import sqlalchemy

from migrate.exceptions import DatabaseNotControlledError
from migrate.versioning import api as versioning_api
from migrate.versioning.repository import Repository

from tionix_client.settings import BASE_DIR
from tionix_client.core.helpers import get_engine
from tionix_client.helpers.i18 import ugettext as _


INIT_VERSION = 0
REPOSITORY_PATH = os.path.join(BASE_DIR, 'db/sqlalchemy/migrate_repo')


_repository = None
_engine = None


def get_db_engine():
    global _engine
    if not _engine:
        _engine = get_engine()
    return _engine


def get_repository():
    global _repository
    if not _repository:
        _repository = Repository(REPOSITORY_PATH)
    return _repository


def db_version():
    repository = get_repository()
    engine = get_db_engine()
    try:
        return versioning_api.db_version(engine, repository)
    except DatabaseNotControlledError:
        meta = sqlalchemy.MetaData()
        meta.reflect(bind=engine)
        tables = meta.tables
        if not tables:
            versioning_api.version_control(
                engine, repository, INIT_VERSION)
            return versioning_api.db_version(engine, repository)
        else:
            raise DatabaseNotControlledError(
                u"Unable to version control DB.")


def migrate(version=None):
    repository = get_repository()
    engine = get_db_engine()
    before_migrate_version = db_version()
    if version is None or version > before_migrate_version:
        versioning_api.upgrade(engine, repository, version)
    else:
        versioning_api.downgrade(engine, repository, version)
    after_migrate_version = db_version()

    msg = _(u'No changes')
    if after_migrate_version != before_migrate_version:
        msg = u'{0} -> {1}'.format(before_migrate_version,
                                   after_migrate_version)
    return os.EX_OK, msg
