# coding: utf-8

# todo Delete when it will be in keystoneclient

import functools

from keystoneclient import base

from tionix_client.helpers.i18 import ugettext as _


def validate(domain_required=True, config_required=True):
    """
    Decorator for validating
    """

    def wraps(f):
        @functools.wraps(f)
        def wrapped(*args, **kwargs):

            if domain_required:
                domain = kwargs.get('domain')
                if not domain:
                    raise ValueError(_('"domain" parameter required'))

            if config_required:
                config = kwargs.get('config')
                if not config:
                    raise ValueError(_('"config" parameter required'))

            return f(*args, **kwargs)
        return wrapped
    return wraps


class DomainConfig(base.Resource):
    """Represents an Identity domain config."""

    pass


class DomainConfigManager(base.Manager):
    """Manager class for manipulating domain config associations.

       Copied from https://review.openstack.org/#/c/168089
    """

    resource_class = DomainConfig
    _response_key = 'config'

    @staticmethod
    def _build_base_url(domain, group=None, option=None):
        domain_id = base.getid(domain)

        api_path = '/domains/%s/config' % domain_id
        if group:
            api_path = '%s/%s' % (api_path, group)
            if option:
                api_path = '%s/%s' % (api_path, option)

        return api_path

    @validate()
    def create(self, domain, config):
        """Create a config for a domain."""

        base_url = self._build_base_url(domain)
        return super(DomainConfigManager, self)._put(url=base_url, body=config)

    @validate(config_required=False)
    def get(self, domain, group=None, option=None):
        """Get a config (or partial config), for a domain."""

        base_url = self._build_base_url(domain, group=group, option=option)
        return super(DomainConfigManager, self)._get(
            url=base_url, response_key=self._response_key)

    @validate(config_required=False)
    def check(self, domain, group=None, option=None):
        """Check a config (or partial config), for a domain."""

        base_url = self._build_base_url(domain, group=group, option=option)
        return super(DomainConfigManager, self)._head(url=base_url)

    @validate()
    def update(self, domain, config, group=None, option=None):
        """Update a config (or partial config), for a domain."""

        base_url = self._build_base_url(domain, group=group, option=option)
        return super(DomainConfigManager, self)._patch(
            url=base_url, body=config, response_key=self._response_key)

    @validate(config_required=False)
    def delete(self, domain, group=None, option=None):
        """Delete a config (or partial config), for a domain."""

        base_url = self._build_base_url(domain, group=group, option=option)
        return super(DomainConfigManager, self)._delete(url=base_url)
