# coding: utf-8

import logging

from tionix_client.functional.writers import BaseWriter


logger = logging.getLogger(__name__)


class Report(object):
    """Class for logging messages to different writers

    Args:
        writers (list): list of BaseWriter subclasses instances

    """
    def __init__(self, writers):
        for writer in writers:
            assert isinstance(writer, BaseWriter)
        self._writers = writers

    def __enter__(self):
        for writer in self._writers:
            writer.init_writer()
        return self

    def write(self, message):
        for writer in self._writers:
            writer.write(message.encode('utf8'))

    def __exit__(self, exc_type, exc_val, exc_tb):
        for writer in self._writers:
            writer.close_writer()
