# coding: utf-8

import logging
import sys
import traceback
from contextlib import contextmanager

from tionix_client.settings import CONF

logger = logging.getLogger(__name__)


@contextmanager
def hidden_traceback(show_tb=CONF.TRACEBACK_ENABLED):
    """
    Loggs uncaught exception.
    show_tb: If True, appends traceback to log.
    """

    def handle_exception(exctype, value, tb):
        msg = u"Unexpected error occurred: {0}".format(value)
        if show_tb:
            exc = u''.join(traceback.format_exception(exctype, value, tb))
            msg = u"{0}\n {1}".format(msg, exc)
        logger.error(msg)

    sys.excepthook = handle_exception
    yield
    sys.excepthook = sys.__excepthook__


def get_from_dict(item, path):
    for key in path.split('.'):
        item = item.get(key)
        if item is None:
            break
    return item


def get_server_ip(server):
    """Get server ip address

    Floating ips have higher priority
    """
    ip = None

    for network in server.addresses.values():
        for ip_group in network:
            ip_type = ip_group.get('OS-EXT-IPS:type')
            ip = ip_group.get('addr')
            if ip and ip_type == 'floating':
                return ip
    return ip


def set_audit_message(req, message):
    environ = getattr(req, 'environ', None)
    if isinstance(environ, dict):
        environ['tnx_audit_message'] = message
