import logging
from functools import partial

from tionix_client.os_clients.nova_client import get_admin_nova_client
from tionix_client.journal.constants import ObjectType
from tionix_client.settings import CONF


logger = logging.getLogger(__name__)


# pylint:disable=too-many-arguments
def log_action(object_id, object_type, action, success=True,
               message=None, user_id=None, user_name=None,
               request_id=None, parent_request_id=None, nova_client=None):
    journal_row = None

    if isinstance(object_id, int):
        object_id = str(object_id)

    try:
        if not nova_client:
            nova_client = get_admin_nova_client(CONF)

        journal_row = nova_client.tnx_journal.create(
            object_id=object_id,
            object_type=object_type,
            action=action,
            user_name=user_name,
            user_id=user_id,
            success=success,
            message=message,
            request_id=request_id,
            parent_request_id=parent_request_id)
    except Exception as err:
        logger.error(u'Failed to log action: %s', err)
    return journal_row


log_server_action = partial(log_action, object_type=ObjectType.Server)
log_node_action = partial(log_action, object_type=ObjectType.Node)
log_project_action = partial(log_action, object_type=ObjectType.Project)
log_request_action = partial(log_action, object_type=ObjectType.Request)
log_user_action = partial(log_action, object_type=ObjectType.User)
