# coding: utf-8
import re
from UserDict import UserDict

import six

# noinspection PyProtectedMember,PyUnresolvedReferences
# pylint: disable=unused-import
from oslo_utils.strutils import (
    _SANITIZE_KEYS, _SANITIZE_PATTERNS_1, _SANITIZE_PATTERNS_2,
    _FORMAT_PATTERNS_1, _FORMAT_PATTERNS_2, mask_password, bool_from_string)


_EXTRA_FORMAT_PATTERNS = [
    # for escaped json like in scheduler task kwargs
    r"(%(key)s\s*\\\":\s*\\\")[^\s^'^\"\\]+",
]


_EXTRA_KEYS = [
    key.upper() for key in _SANITIZE_KEYS if key.upper() not in _SANITIZE_KEYS]

_EXTRA_KEYS.extend(['auth_password', 'AUTH_PASSWORD'])

for key in _EXTRA_KEYS:
    _SANITIZE_KEYS.append(key)
    _SANITIZE_PATTERNS_1[key] = []
    _SANITIZE_PATTERNS_2[key] = []

    for pattern in _FORMAT_PATTERNS_2:
        reg_ex = re.compile(pattern % {'key': key}, re.DOTALL)
        _SANITIZE_PATTERNS_2[key].append(reg_ex)

    for pattern in _FORMAT_PATTERNS_1:
        reg_ex = re.compile(pattern % {'key': key}, re.DOTALL)
        _SANITIZE_PATTERNS_1[key].append(reg_ex)


# oslo_utils doesn't allow to extend regexp patterns list so we have to
# mutate the original
# oslo_utils.strutils.py:82
for key in _SANITIZE_KEYS:
    for pattern in _EXTRA_FORMAT_PATTERNS:
        reg_ex = re.compile(pattern % {'key': key}, re.DOTALL)
        _SANITIZE_PATTERNS_1[key].append(reg_ex)


_EXCLUDE_KEYS = ['USE_VDI_TOKEN']


# extended oslo_utils mask_dict_password by exclude keys and userdict support
def mask_dict_password(dictionary, secret="******"):
    """Replace password with *secret* in a dictionary recursively.
    """

    if not isinstance(dictionary, (dict, UserDict)):
        raise TypeError("Expected a dictionary, got %s instead."
                        % type(dictionary))
    out = {}
    for k, v in dictionary.items():
        if isinstance(v, (dict, UserDict)):
            out[k] = mask_dict_password(v, secret=secret)
            continue

        k_matched = False
        if isinstance(k, six.string_types):
            for sani_key in _SANITIZE_KEYS:
                if sani_key in k and k not in _EXCLUDE_KEYS:
                    out[k] = secret
                    k_matched = True
                    break
        if not k_matched:
            if isinstance(v, six.string_types):
                out[k] = mask_password(v, secret=secret)
            else:
                out[k] = v
    return out
