# coding: utf-8

from novaclient import base


class HostClassesResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_host_classes'
    _version = None


class HostClassesManager(base.ManagerWithFind):

    resource_class = HostClassesResource
    alias = 'tnx-host-classes'
    collection_name = 'host-classes'
    member_name = 'host-class'
    member_alias = 'host-class'

    def get(self, identifier):
        return self._get(
            '/{0}/{1}'.format(self.alias, base.getid(identifier)),
            self.member_name)

    def list(self):
        return self._list('/{0}'.format(self.alias), self.collection_name)

    def create(self, name, host_types=None):
        """
        POST method to create host class
        """
        body = {"name": name}
        if host_types:
            body['host-types'] = host_types
        return self._create(
            '/{0}'.format(self.alias),
            {self.member_alias: body},
            self.member_name)

    def update(self, identifier, name=None, host_types=None):
        """
        POST method to update host class
        """
        body = {}
        if name:
            body['name'] = name

        if host_types:
            body['host-types'] = host_types

        return self._update(
            '/{0}/{1}'.format(self.alias, identifier),
            {self.member_alias: body},
            self.member_name)

    def delete(self, identifier):
        self._delete('/{0}/{1}'.format(self.alias, base.getid(identifier)))

    def create_host_type(self, identifier, **kwargs):
        _resp, body = self.api.client.post(
            '/{0}/{1}/action'.format(self.alias, identifier),
            body={'create-host-type': kwargs})
        return body

    def update_host_type(self, identifier, host_type_id, **kwargs):

        body = {'id': host_type_id}
        body.update(**kwargs)

        _resp, body = self.api.client.post(
            '/{0}/{1}/action'.format(self.alias, identifier),
            body={'update-host-type': body})
        return body

    def delete_host_type(self, identifier, host_type_id):

        _resp, body = self.api.client.post(
            '/{0}/{1}/action'.format(self.alias, identifier),
            body={'delete-host-type': {'id': host_type_id}})
        return body


class HostClassesClientExtension(object):
    name = 'tnx_host_classes'
    manager_class = HostClassesManager
