# coding: utf-8

"""
Hosts interface.
"""

from six.moves.urllib import parse

from novaclient.base import getid
from novaclient.v2.hosts import HostManager as NovaHostManager


class TNXHostManager(NovaHostManager):
    alias = 'tnx-os-hosts'

    def evacuate(self, identifier):
        return self._action(
            'tnx-cc-evacuate',
            identifier
        )

    def shutdown(self, identifier, allow_off_vm=False, allow_evacuate=False):
        return self._action(
            'tnx-cc-shutdown',
            identifier,
            {
                'allow-off-vm': allow_off_vm,
                'allow-evacuate': allow_evacuate
            }
        )

    def _action(self, action, node, info=None, **kwargs):
        """
        Perform a host "action".
        """
        body = {action: info}
        self.run_hooks('modify_body_for_action', body, **kwargs)
        url = '/{0}/{1}/action'.format(self.alias, getid(node))
        return self.api.client.post(url, body=body)

    def restart_hosts(self, hosts, allow_off_vm, allow_evacuate, in_sequence):
        _resp, body = self.api.client.get(
            u"/{0}/restart_hosts?{1}".format(
                self.alias,
                parse.urlencode({
                    'hosts': u','.join(hosts),
                    'allow_off_vm': allow_off_vm,
                    'allow_evacuate': allow_evacuate,
                    'in_sequence': in_sequence})))
        return body


class TNXHostExtension(object):
    name = 'hosts'
    manager_class = TNXHostManager
