# coding: utf-8

"""
Manager working with journal table
"""

import uuid
import logging

from tionix_client.core.manager_db import BaseDBManager
from tionix_client.journal.models import Journal, ActionStatus


logger = logging.getLogger(__name__)


class JournalManager(BaseDBManager):
    """
    Journal manager
    """

    model = Journal
    exclude_update_keys = ('id',)
    default_order_field = 'event_time'

    # pylint:disable=too-many-arguments
    @classmethod
    def log_action(
            cls, object_id, object_type, action, action_arguments=None,
            status=None, message=None, response_code=None, user_id=None,
            user_name=None, request_id=None, parent_request_id=None,
            event_time=None, is_notification=None):

        request_id = request_id or cls.generate_req_id()
        if status not in ActionStatus.TYPES:
            status = ActionStatus.UNKNOWN

        return cls.create(
            object_id=object_id,
            object_type=object_type,
            action=action,
            event_time=event_time,
            is_notification=is_notification,
            action_arguments=action_arguments,
            status=status,
            message=message,
            response_code=response_code,
            user_id=user_id,
            user_name=user_name,
            request_id=request_id,
            parent_request_id=parent_request_id)

    @staticmethod
    def generate_req_id():
        return 'tnx-{0}'.format(str(uuid.uuid4()))
