import logging

from tionix_client.journal.parsers.base import BaseEventParser, Target

logger = logging.getLogger(__name__)


class KeystoneEventParser(BaseEventParser):
    RESOURCE_MAPPING = {
        'project': {
            'target_type': 'project'
        }
    }

    service_name = 'keystone'

    @classmethod
    def _parse_resource_target(cls, payload, resource_type, mapping):
        action_name = '{0}.{1}'.format(
            cls.service_name,
            cls._format_str(payload.get('action')).replace('/', '.'))
        argument_keys = 'project', 'group', 'user', 'role'
        targets = []
        resource_id = None
        resource_target_type = mapping.get('target_type')
        action_params = {}

        target_obj = payload.get('target') or {}
        obj_type = (target_obj.get('typeURI') or '').split('/')[-1]
        if obj_type == resource_target_type:
            resource_id = target_obj.get('id')
        elif resource_target_type in payload:
            resource_id = payload.get(resource_target_type)

        if resource_id:
            for key in argument_keys:
                if key != resource_target_type and key in payload:
                    action_params.update({key: payload.get(key)})
            targets = [Target(
                object_id=resource_id,
                object_type=resource_type,
                action=action_name,
                action_arguments=action_params)]
        return targets
