# coding: utf-8

"""
Licenses info client.
"""

from novaclient import base


class LicenseResource(base.Resource):
    HUMAN_ID = True

    def __repr__(self):
        return '<License: %s>' % self.name


class BaseLicenseManager(base.ManagerWithFind):
    resource_class = LicenseResource
    is_alphanum_id_allowed = True
    alias = 'tnx-licenses'
    collection_name = ''
    member_name = 'license'
    member_alias = 'license'

    # pylint: disable=arguments-differ
    def list(self, detailed=True):
        return self._list(
            '/{0}{1}'.format(
                self.alias,
                '/detail' if detailed else ''),
            self.collection_name
        )

    def get(self, identifier):
        return self._get(
            '/{0}/{1}'.format(
                self.alias, base.getid(identifier)),
            self.member_name)


class TnxCloudControlLicenseManager(BaseLicenseManager):
    collection_name = 'cc_licenses'

    def get_cloud_control_info(self):
        return self.get('tionix_cloud_control')


class TnxNodeControlLicenseManager(BaseLicenseManager):
    collection_name = 'nc_licenses'

    def get_node_control_info(self):
        return self.get('tionix_node_control')


class TnxMonitorLicenseManager(BaseLicenseManager):
    collection_name = 'monitor_licenses'

    def get_monitor_info(self):
        return self.get('tionix_monitor')


class TnxVDIServerLicenseManager(BaseLicenseManager):
    collection_name = 'vdi_server_licenses'

    def get_vdi_server_info(self):
        return self.get('tionix_vdi_server')


class CloudControlLicenseClientExtension(object):
    name = 'cc_licenses'
    manager_class = TnxCloudControlLicenseManager


class NodeControlLicenseClientExtension(object):
    name = 'nc_licenses'
    manager_class = TnxNodeControlLicenseManager


class MonitorLicenseClientExtension(object):
    name = 'monitor_licenses'
    manager_class = TnxMonitorLicenseManager


class VDIServerLicenseClientExtension(object):
    name = 'vdi_server_licenses'
    manager_class = TnxVDIServerLicenseManager
