# coding: utf-8

import logging.config

from tionix_client.helpers.log import setup_module_logger

from tionix_client.settings import CONF

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default': {
            'format': '%(asctime)s.%(msecs)03d %(process)d %(levelname)s '
                      '%(name)s [-] %(message)s',
            'datefmt': '%Y-%m-%d %H:%M:%S',
        },
        'WithExceptions': {
            '()': 'tionix_client.helpers.log.FormatterWithExceptions',
            'show_traceback': CONF.TRACEBACK_ENABLED,
            'format': '%(asctime)s.%(msecs)03d %(process)d %(levelname)s '
                      '%(name)s [-] %(message)s',
            'datefmt': '%Y-%m-%d %H:%M:%S',
        },
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default',
        },
        'consoleTraceback': {
            'class': 'logging.StreamHandler',
            'formatter': 'WithExceptions'
        }
    },
    'loggers': {
        'tionix_client': {
            'handlers': ['consoleTraceback'],
            'propagate': False,
        },
        '__main__': {
            'handlers': ['consoleTraceback'],
            'propagate': False,
        },
        'amqp': {
            'handlers': ['console'],
            'level': 'WARNING',
            'propagate': False,
        },
    },
}


def setup_logging(logging_conf=None, initial_setup=False):
    if initial_setup:
        setup_module_logger('tionix_client',
                            force_tb=CONF.TRACEBACK_ENABLED)
    else:
        logging_conf = logging_conf or LOGGING
        logging.config.dictConfig(logging_conf)
        log_root = logging.getLogger()
        log_root.setLevel(CONF.LOG_LEVEL)
