# coding: utf-8
# pylint:disable=too-many-arguments

import logging

from glanceclient.client import Client as GlanceClient

from tionix_client.settings import CONF
from tionix_client.os_clients.keystone_client import get_keystone_client

logger = logging.getLogger(__name__)


def get_glance_client(token=None, username=None, password=None,
                      tenant=None, tenant_id=None, user_domain_name=None,
                      project_domain_name=None, keystone_client=None,
                      user_locale=None):
    """Function to get glance client by provided params.

    :param token: auth token
    :param username: auth name
    :param password: auth password
    :param tenant: tenant name
    :param tenant_id: tenant id
    :param user_domain_name: user_domain_name
    :param project_domain_name : project_domain_name
    :param keystone_client: keystone_client
    :param user_locale: user locale
    """

    if not keystone_client:
        keystone_client = get_keystone_client(
            token=token, username=username, password=password, tenant=tenant,
            tenant_id=tenant_id, user_domain_name=user_domain_name,
            project_domain_name=project_domain_name)

    service_type = CONF.KEYSTONE['image_service_name']

    kwargs = {}
    if user_locale:
        kwargs['language_header'] = user_locale

    try:
        glance_client = GlanceClient(
            version=CONF.GLANCE_VERSION,
            session=keystone_client.session,
            service_type=service_type,
            **kwargs)
    except Exception as err:
        logger.error(unicode(err))
        raise err

    return glance_client
