# coding: utf-8
# pylint:disable=too-many-arguments

import logging

from neutronclient.neutron.client import Client as NeutronClient

from tionix_client.os_clients.base import KeystoneSessionProxy
from tionix_client.settings import CONF
from tionix_client.os_clients.keystone_client import get_keystone_client

logger = logging.getLogger(__name__)


def get_neutron_client(token=None, username=None, password=None,
                       tenant=None, tenant_id=None, user_domain_name=None,
                       project_domain_name=None, keystone_client=None,
                       user_locale=None):
    """Function to get neutron client by provided params.

    :param token: auth token
    :param username: auth name
    :param password: auth password
    :param tenant: tenant name
    :param tenant_id: tenant id
    :param user_domain_name: user_domain_name
    :param project_domain_name: project_domain_name
    :param keystone_client: keystone_client
    :param user_locale: user locale
    """
    if not keystone_client:
        keystone_client = get_keystone_client(
            token=token, username=username, password=password,
            tenant=tenant, tenant_id=tenant_id,
            user_domain_name=user_domain_name,
            project_domain_name=project_domain_name)

    service_type = CONF.KEYSTONE['network_service_name']

    try:
        client = NeutronClient(
            api_version=CONF.NEUTRON_VERSION,
            session=KeystoneSessionProxy(
                keystone_client.session,
                additional_headers={'Accept-Language': user_locale}
            ),
            service_type=service_type)
    except Exception as err:
        logger.error(unicode(err))
        raise err

    return client


def neutron_client(req, project_id=None):
    context = req.environ['nova.context']
    token = getattr(context, 'auth_token', None)
    tenant_id = project_id or getattr(context, 'tenant', None)
    return get_neutron_client(token=token, tenant_id=tenant_id)
