import os

import prettytable
from cliff.formatters.table import TableFormatter


def move_header_to_first_row(table):
    """Hide table header and put it into table."""
    header = table.field_names
    table.header = False
    table.hrules = prettytable.ALL
    # noinspection PyProtectedMember
    table._rows.insert(0, header)


class TnxTableFormatter(TableFormatter):

    # pylint: disable=arguments-differ, keyword-arg-before-vararg
    @staticmethod
    def _assign_max_widths(stdout, table, max_width, min_width=0, *args):
        # prettytable doesn't support linebreaks in headers, so we add
        # headers to rows and print table without headers
        move_header_to_first_row(table)

        # customize table
        table.padding_width = 0
        min_width = 5

        # noinspection PyArgumentList
        TableFormatter._assign_max_widths(stdout, table, max_width, min_width,
                                          *args)

    def add_argument_group(self, parser):
        # Do not inherit parent class method to avoid
        # duplicate arguments conflict
        pass

    def emit_list(self, column_names, data, stdout, parsed_args):
        fit_width_set_explicitly = 'CLIFF_FIT_WIDTH' in os.environ
        if 'fit_width' in parsed_args and not fit_width_set_explicitly:
            # Applies only to cliff v2. By default, fit_width is set to False.
            # We want it to be True to have proper formatting.
            parsed_args.fit_width = True
        return super(TnxTableFormatter, self).emit_list(
            column_names, data, stdout, parsed_args)
