# coding: utf-8

from tionix_client.helpers.i18 import ugettext as _
from tionix_client.helpers.table import build_wrapped_table


class ModuleResult(object):
    def __init__(self, module_name, result_code, result_message):
        self.module_name = module_name
        self.result_code = result_code
        self.result_message = result_message


class ResultParser(object):

    header = (u'N', _(u'Module name'), _(u'Status'), _(u'Result'))
    table_name = None

    def __init__(self):
        self.was_successful = True
        self.results = []
        self.result_table = []

    def add_result(self, module_name, result):
        result_code, result_message = result
        self.results.append(
            ModuleResult(module_name, result_code, result_message))

    def get_rows(self):
        def code_to_str(code):
            return _(u'FAIL') if code else _(u'OK')

        return [[i, result.module_name, code_to_str(result.result_code),
                 result.result_message] for i, result in
                enumerate(self.results, 1)]

    def make_table(self):
        rows = self.get_rows()

        formatted_table = build_wrapped_table(self.header, rows)
        return formatted_table + '\n'

    def get_results(self):
        table_data = self.make_table()
        table_name = self.table_name or u''
        self.result_table = (
            u"{border}\n"
            u"{table_name}\n"
            u"{border}\n"
            u"{table_data}"
        ).format(
            table_name=table_name,
            border="=" * len(table_name),
            table_data=table_data
        )
        return self.result_table
