# coding: utf-8

import logging
import os

from tionix_client.helpers.i18 import ugettext as _
from tionix_client.osc.helpers import (
    get_available_module_names, show_available_modules,
    parse_module_names, OSC_SILENT_LEVEL, run_modules_command, Command)
from tionix_client.osc.parser import ResultParser
from tionix_client.osc.v1 import CONFIGURE_GROUP


logger = logging.getLogger(__name__)

available_module_names = get_available_module_names(CONFIGURE_GROUP)


class ConfigureParser(ResultParser):

    table_name = _(u'Configuration table')


class RunConfigure(Command):
    """Configure TIONIX modules."""

    auth_required = False

    def take_action(self, parsed_args):
        if parsed_args.list:
            show_available_modules(CONFIGURE_GROUP)
            return os.EX_OK

        names = parsed_args.module_names
        if names:
            names = parse_module_names(available_module_names, names)

        verbose = self.app.options.verbose_level > OSC_SILENT_LEVEL
        func_kwargs = {'verbose': verbose}
        return run_modules_command(
            group=CONFIGURE_GROUP,
            parser=ConfigureParser(),
            module_names=names,
            func_kwargs=func_kwargs,
        )

    def get_parser(self, prog_name):
        """Return an :class:`argparse.ArgumentParser`.
        """

        parser = super(RunConfigure, self).get_parser(prog_name)

        group = parser.add_mutually_exclusive_group()
        help_msg = (_(u'Names of the modules to configure. Choose from: {0}'
                      u'').format(available_module_names))
        group.add_argument(
            '-n', '--names',
            help=help_msg,
            dest='module_names',
            nargs='+',
            default=None)
        group.add_argument(
            '-l', '--list',
            help=_(u'List all modules supporting configuration'),
            action='store_true')

        return parser
