# coding: utf-8

import logging

from tionix_client.osc.parser import ResultParser
from tionix_client.osc.helpers import (
    get_available_module_names, parse_module_names,
    OSC_SILENT_LEVEL, run_modules_command, Command
)
from tionix_client.helpers.i18 import ugettext as _
from tionix_client.osc.v1 import DB_LIST_GROUP

available_module_names = get_available_module_names(DB_LIST_GROUP)

logger = logging.getLogger(__name__)


class DbMigrateVersionParser(ResultParser):

    header = (u'N', _(u'Module name'), _(u'Status'), _(u'Version'))
    table_name = _(u'DB migrate versions table')


class ListDbMigrateVersions(Command):
    """
    List TIONIX module's migration versions.
    """
    auth_required = False

    def take_action(self, parsed_args):
        names = parsed_args.module_names
        verbose = self.app.options.verbose_level > OSC_SILENT_LEVEL
        if names:
            names = parse_module_names(available_module_names, names)

        func_kwargs = {'verbose': verbose}
        return run_modules_command(
            group=DB_LIST_GROUP,
            parser=DbMigrateVersionParser(),
            module_names=names,
            func_kwargs=func_kwargs
        )

    def get_parser(self, prog_name):
        """Return an :class:`argparse.ArgumentParser`.
        """
        parser = super(ListDbMigrateVersions, self).get_parser(prog_name)

        help_msg = (_(u'Names of the modules to show actual migrate versions. '
                      u'Choose from: {0}').format(available_module_names))
        parser.add_argument(
            '-n', '--names',
            help=help_msg,
            dest='module_names',
            nargs='+',
            default=None)

        return parser
