# coding: utf-8

import logging
import os

from tionix_client.helpers.i18 import ugettext as _
from tionix_client.osc.exceptions import OptionError
from tionix_client.osc.helpers import (
    get_available_module_names, show_available_modules, parse_module_names,
    OSC_SILENT_LEVEL, run_modules_command, Command)
from tionix_client.osc.parser import ResultParser
from tionix_client.osc.v1 import DB_MIGRATES_GROUP

available_module_names = get_available_module_names(DB_MIGRATES_GROUP)
logger = logging.getLogger(__name__)


class DbMigrateParser(ResultParser):

    table_name = _(u'DB migrate table')


class RunDbMigrate(Command):
    """
    Run TIONIX module's db migrate.
    """

    auth_required = False

    def take_action(self, parsed_args):
        if parsed_args.list:
            show_available_modules(DB_MIGRATES_GROUP)
            return os.EX_OK

        names = parsed_args.module_names
        migration = parsed_args.migration
        verbose = self.app.options.verbose_level > OSC_SILENT_LEVEL

        if names:
            names = parse_module_names(available_module_names, names)
            if len(names) != 1 and migration:
                raise OptionError(
                    _(u'Option --migration allowed only with single module'
                      u'')
                )

        func_kwargs = {
            'migration': migration,
            'verbose': verbose
        }
        return run_modules_command(
            group=DB_MIGRATES_GROUP,
            parser=DbMigrateParser(),
            module_names=names,
            func_kwargs=func_kwargs
        )

    def get_parser(self, prog_name):
        """Return an :class:`argparse.ArgumentParser`.
        """

        parser = super(RunDbMigrate, self).get_parser(prog_name)

        group = parser.add_mutually_exclusive_group()
        help_msg = (_(u'Names of the modules to db migrate. Choose from: {0}'
                      u'').format(available_module_names))
        group.add_argument(
            '-n', '--names',
            help=help_msg,
            dest='module_names',
            nargs='+',
            default=None)
        group.add_argument(
            '-l', '--list',
            help=_(u'List all modules supporting db migrates'),
            action='store_true')
        parser.add_argument(
            '--migration',
            help=_(u'Specific migration version'),
            required=False)

        return parser
