# coding: utf-8

import json
from functools import partial

import requests

from cliff import lister
from keystoneclient.exceptions import EndpointNotFound

from tionix_client.settings import CONF
from tionix_client.os_clients.keystone_client import get_keystone_client
from tionix_client.osc.exceptions import (
    ConnectionError, OptionError, ResponseError)
from tionix_client.osc.helpers import get_osc_opts
from tionix_client.helpers.i18 import ugettext as _


class ListExtensions(lister.Lister):
    """
    Retrieve the plugins list from nova service.
    """

    auth_required = False

    def take_action(self, parsed_args):
        connect_opts = get_osc_opts(self.app.options)

        try:
            # pylint doesn't recognize dict items pop here
            keystone_cl = get_keystone_client(  # pylint: disable=E1123
                **connect_opts)
        except Exception as err:
            raise ConnectionError(
                u'Could not authenticate in Keystone. {0}'.format(err)
            )

        volume_service_name = CONF.KEYSTONE['volume_service_name']
        compute_service_name = CONF.KEYSTONE['compute_service_name']

        url_for_compute = self.get_url_for_service(keystone_cl,
                                                   compute_service_name)
        url_for_volume = self.get_url_for_service(keystone_cl,
                                                  volume_service_name)

        tenant = url_for_compute.replace('//', '/').split('/')[3]

        print u'url_for_volume ', url_for_volume
        print u'url_for_compute', url_for_compute
        print u'token=' + keystone_cl.auth_token
        print u'tenant=' + tenant

        filter_key = unicode(parsed_args.filter).lower()
        columns = (u'#', u'Name', u'Alias', u'Description')
        data = []
        for extension in self.get_extensions(keystone_cl, url_for_compute):
            # filter by key in name and alias occurrences
            name = extension.get('name')
            alias = extension.get('alias')
            description = (extension.get('description') or '').strip()
            filter_key_in_alias = (filter_key in alias.lower())
            filter_key_in_name = (filter_key in name.lower())

            if not filter_key or (filter_key_in_alias or filter_key_in_name):
                data.append((len(data) + 1, name, alias, description))

        return columns, data

    def get_parser(self, prog_name):
        """Return an :class:`argparse.ArgumentParser`.
        """

        parser = super(ListExtensions, self).get_parser(prog_name)
        utf8 = partial(unicode, encoding='utf-8')
        parser.add_argument(
            '--filter',
            required=False,
            default='',
            type=utf8,
            help=_(u'Filter extensions by key'),
        )

        return parser

    @staticmethod
    def get_extensions(keystone_cl, url_for_compute=None):
        """
        Fetch all extensions
        :param url_for_compute:
        :param keystone_cl: keystone client object
        :return: extension list
        """
        response = requests.get(
            url_for_compute + '/extensions',
            headers={
                'X-Auth-Token': keystone_cl.auth_token
            })

        try:
            extensions = json.loads(response.text)['extensions']
        except (ValueError, KeyError):
            raise ResponseError(
                _(u'We have bad response here: status - {0}, {1}').format(
                    response.status_code, response.text))

        return extensions

    @staticmethod
    def get_url_for_service(keystone_cl, service_type):
        endpoint_type = 'publicURL'
        try:
            url_for_service = (
                keystone_cl.session.auth.auth_ref.service_catalog.url_for(
                    service_type=service_type, interface=endpoint_type))
        except EndpointNotFound as exc:
            raise OptionError(u'Invalid option: {0}. {1}'.format(
                service_type, exc))
        else:
            return url_for_service
