# coding: utf-8

from urllib import urlencode

from novaclient import base


class PXEImageResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_pxe_image'
    _version = None


class PXEImagesManager(base.ManagerWithFind):

    resource_class = PXEImageResource
    alias = 'tnx-pxe-images'

    def get(self, identifier):
        return self._get(
            '/{0}/{1}'.format(self.alias, base.getid(identifier)),
            'pxe-image')

    # pylint: disable=arguments-differ
    def list(self, detailed=False, limit=None, offset=None):

        qparams = {}
        if limit:
            qparams['limit'] = limit
        if offset:
            qparams['offset'] = offset

        query = ''
        if qparams:
            query = '?{0}'.format(urlencode(qparams))

        url = '/{0}{1}{2}'.format(
            self.alias,
            '/detail' if detailed else '',
            query)
        return self._list(url, 'pxe-images')

    def create(self, image_name, file_data):
        """
        POST method to create PXE image
        """
        url = '/{0}'.format(self.alias)
        body = {
            "pxe-image": {
                "image-name": image_name,
                "file-data": file_data,
            }
        }
        return self.api.client.post(url, body=body)

    def delete(self, identifier):
        self._delete('/{0}/{1}'.format(self.alias, base.getid(identifier)))


class PXEImagesClientExtension(object):
    name = 'tnx_pxe_images'
    manager_class = PXEImagesManager
