# coding: utf-8
from urllib import urlencode
import six

from novaclient import base


class SessionResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_sessions'
    _version = None


class SessionManager(base.ManagerWithFind):
    resource_class = SessionResource
    alias = 'tnx-sessions'

    def _build_list_request(self, user_id=None, instance_id=None,
                            domain_id=None, limit=None, offset=None,
                            **filters):
        qparams = {}

        if user_id:
            qparams['user_id'] = user_id
        if instance_id:
            qparams['instance_id'] = instance_id
        if domain_id:
            qparams['domain_id'] = domain_id
        if limit:
            qparams['limit'] = limit
        if offset:
            qparams['offset'] = offset

        if filters:
            for opt, val in six.iteritems(filters):
                if val:
                    if isinstance(val, six.text_type):
                        val = val.encode('utf-8')
                    qparams[opt] = val

        return '/{0}{1}'.format(
            self.alias,
            '?{0}'.format(urlencode(qparams, doseq=True))
        )

    def create(self, **kwargs):
        """
        POST method to create session
        """
        body = {
            'session-info': kwargs
        }
        url = '/{0}/add_session'.format(self.alias)
        return self.api.client.post(url, body=body)

    # pylint: disable=arguments-differ
    def list(self, user_id=None, instance_id=None, domain_id=None, limit=None,
             offset=None, **filters):

        return self._list(
            self._build_list_request(user_id=user_id, instance_id=instance_id,
                                     domain_id=domain_id, limit=limit,
                                     offset=offset, **filters),
            'sessions')

    def count(self, user_id=None, instance_id=None, **filters):

        qparams = {}

        if user_id:
            qparams['user_id'] = user_id
        if instance_id:
            qparams['instance_id'] = instance_id
        if filters:
            for opt, val in six.iteritems(filters):
                if val:
                    if isinstance(val, six.text_type):
                        val = val.encode('utf-8')
                    qparams[opt] = val

        _resp, body = self.api.client.get(
            u'/{0}/count{1}'.format(self.alias,
                                    u'?{0}'.format(urlencode(qparams,
                                                             doseq=True)))
        )
        return body['count']


class SessionClientExtension(object):
    name = 'tnx_sessions'
    manager_class = SessionManager
