# coding: utf-8

import os

from tionix_client.settings.loader import Config
from tionix_client.settings.validators import validators_map

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

MODULE_NAME = 'tionix_client'

DEFAULT_CONF = {
    'NOVA_VERSION': 2.25,
    'CINDER_VERSION': 2,
    'CEILOMETER_VERSION': 2,
    'GLANCE_VERSION': 2,
    'NEUTRON_VERSION': 2,
    'KEYSTONE': {
        'auth_url': 'http://localhost:5000',
        'auth_version': '3',
        'auth_user': 'admin',
        'auth_password': 'admin',
        'auth_tenant': 'admin',
        'compute_service_name': 'compute',
        'image_service_name': 'image',
        'network_service_name': 'network',
        'volume_service_name': 'volumev2',
        'ceilometer_service_name': 'metering',
        'user_domain_name': 'default',
        'project_domain_name': 'default'
    },
    'DB': {
        'ENGINE': 'mysql+pymysql',
        'USER': 'tionix',
        'PASSWORD': 'password',
        'HOST': 'localhost',
        'PORT': '3306',
        'NAME': 'tionix'
    },
    'RABBIT_QUEUES': {
        'broker_type': 'amqp',
        'host': 'localhost',
        'port': '5672',
        'username': 'tionix',
        'password': 'password',
    },
    'LOG_LEVEL': 'INFO',
    'DB_CONNECTION_MAX_RETRIES': 2,
    'TRACEBACK_ENABLED': False,
    'NOVA_RABBIT_VHOST': '/',
    'KEYSTONE_RABBIT_VHOST': '/'
}

CONFIG_PATH = '/etc/tionix/tionix.yaml'

immutable_variables = ['NOVA_VERSION']
unused_variables = ['CINDER_VERSION', 'DB', 'RABBIT_QUEUES', 'AUTH_VERSION',
                    'RAVEN', 'SENTRY']


CONF = Config(
    config_files=[CONFIG_PATH],
    default_settings=DEFAULT_CONF,
    validators=validators_map,
    immutable_variables=immutable_variables,
    unused_variables=unused_variables,
    module_name=MODULE_NAME)


def get_db_connection_url(conf, db_name=None):
    template = (
        u'{ENGINE}://{USER}:{PASSWORD}@{HOST}:{PORT}/{NAME}?charset=utf8')
    params = dict(**conf.DB)
    if db_name:
        params['NAME'] = db_name
    return template.format(**params)


def get_rabbit_broker_url(conf, vhost=None):
    params = dict(**conf.RABBIT_QUEUES)
    if vhost:
        params['vhost'] = vhost

    template = u"{broker_type}://{username}:{password}@{host}:{port}/{vhost}"
    return template.format(**params)
