# coding: utf-8

import six

# pylint: disable=import-error, relative-import
from six.moves.urllib import parse

from novaclient import base


class TenantResource(base.Resource):
    HUMAN_ID = True

    _module_name = 'tnx_tenant'
    _version = None


class TenantManager(base.ManagerWithFind):

    resource_class = TenantResource
    alias = 'tnx-tenants'

    def get(self, tenant_id, only_vdi_vm=False):

        qparams = {}
        if only_vdi_vm:
            qparams['only_vdi_vm'] = only_vdi_vm

        query = ""
        if qparams:
            query = "?" + parse.urlencode(qparams)

        return self._get(
            '/{0}/{1}{2}'.format(self.alias, tenant_id, query),
            'tenant'
        )

    # pylint: disable=arguments-differ
    def list(self, detailed=True, limit=None, marker=None,
             enabled=None, domain=None, user=None, **kwargs):

        qparams = {}
        if limit:
            qparams['limit'] = limit
        if marker:
            qparams['marker'] = marker
        if enabled is not None:
            qparams['enabled'] = enabled
        if domain is not None:
            qparams['domain_id'] = domain
        if user is not None:
            qparams['user_id'] = user

        for opt, val in six.iteritems(kwargs.get('filters', {})):
            if val:
                if isinstance(val, six.text_type):
                    val = val.encode('utf-8')
            qparams[opt] = val

        query = ""
        if qparams:
            query = "?" + parse.urlencode(qparams)

        detail = ""
        if detailed:
            detail = "/detail"

        url = '/{0}{1}{2}'.format(self.alias, detail, query)
        return self._list(url, 'tenants')

    def create(self, **kwargs):
        """
        POST method to create tenant
        """
        url = '/{0}'.format(self.alias)
        body = {"tenant-info": kwargs}
        return self.api.client.post(url, body=body)

    @staticmethod
    def _build_body(**kwargs):
        return {
            'tenant-info': {
                k: v for k, v in kwargs.iteritems() if v is not None
            }
        }

    def update(self, identifier, **kwargs):

        body = self._build_body(**kwargs)

        return self._update(
            '/{0}/{1}'.format(self.alias, base.getid(identifier)),
            body,
            'tenant'
        )

    def delete(self, identifier):
        self._delete('/%s/%s' % (self.alias, base.getid(identifier)))

    def add_security_group(self, tenant_id, security_group_id):
        """ Add security group
        """
        body = {
            'add-security-group': {'security_group_id': security_group_id}
        }
        url = '/{0}/{1}/action'.format(self.alias, base.getid(tenant_id))
        return self.api.client.post(url, body=body)

    def delete_security_group(self, tenant_id, security_group_id):
        """ Delete security group
        """
        body = {
            'delete-security-group': {'security_group_id': security_group_id}
        }
        url = '/{0}/{1}/action'.format(self.alias, base.getid(tenant_id))
        return self.api.client.post(url, body=body)


class TenantClientExtension(object):
    name = 'tnx_tenants'
    manager_class = TenantManager
