# coding: utf-8

import unittest

from multiprocessing import Queue

import pkg_resources

import mock

from tionix_client.osc import helpers
from tionix_client.osc.helpers import run_module_ep
from tionix_client.osc.v1 import TESTS_GROUP
from tionix_client.osc.v1.tests import run_modules_tests


class FakeEntryPoint(object):
    name = 'fake_module'
    fake_test = mock.Mock(return_value=True)

    # noinspection PyUnusedLocal
    def load(self, require=True, *args, **kwargs):
        return self.resolve()

    def resolve(self):
        return self.fake_test


class FuncTestsRunnerTestCase(unittest.TestCase):
    # pylint: disable=attribute-defined-outside-init
    @mock.patch('tionix_client.functional.settings.read_default_settings',
                new=mock.Mock(return_value={}))
    def test_run_modules_tests(self):
        self._iter_entry_points = pkg_resources.iter_entry_points
        pkg_resources.iter_entry_points = mock.Mock(
            return_value=[FakeEntryPoint])
        result = run_modules_tests('invalid_module')
        self.assertTrue(result)
        pkg_resources.iter_entry_points = self._iter_entry_points

    def test_run_single_test(self):
        queue = Queue()
        func_kwargs = {'test': 1}
        run_module_ep(FakeEntryPoint(), queue, TESTS_GROUP,
                      func_kwargs=func_kwargs)
        result = queue.get()
        FakeEntryPoint.fake_test.assert_called_with(**func_kwargs)
        self.assertTrue(result)


class VersionTestCase(unittest.TestCase):
    class MockDistribution(object):
        version = u'1.0.0'

    def setUp(self):
        self.get_distribution = pkg_resources.get_distribution
        pkg_resources.get_distribution = mock.Mock(
            return_value=self.MockDistribution)

    def test_get_version_returns_value(self):
        version = helpers.get_version()
        self.assertEqual(version, self.MockDistribution.version)

    def tearDown(self):
        pkg_resources.get_distribution = self.get_distribution


class VersionInvalidTestCase(unittest.TestCase):
    def setUp(self):
        self.get_package_name = helpers.get_package_name
        helpers.get_package_name = mock.Mock(
            return_value=u'invalid_package_name')

    def test_get_version_returns_none(self):
        version = helpers.get_version()
        self.assertIsNone(version)

    def tearDown(self):
        helpers.get_package_name = self.get_package_name


@mock.patch('pkg_resources.get_distribution',
            new=mock.Mock(side_effect=pkg_resources.VersionConflict))
class VersionConflictTestCase(unittest.TestCase):

    def test_version_conflict(self):
        version = helpers.get_version()
        self.assertIsNone(version)
