# coding: utf-8

import os
import tempfile
import unittest

from tionix_client.functional.locker import FileLocker, LockError


class FileLockerTestCase(unittest.TestCase):

    def setUp(self):
        _id, self.filename = tempfile.mkstemp()

    def tearDown(self):
        os.remove(self.filename)

    def test_lock_file(self):
        test_content = 'test\n'

        locker = FileLocker(self.filename)
        self.assertFalse(locker.is_locked())

        fh = open(self.filename, 'w')
        locker.lock()

        fh.write(test_content)
        self.assertTrue(locker.is_locked())

        locker2 = FileLocker(self.filename)
        self.assertTrue(locker2.is_locked())
        self.assertRaises(LockError, locker2.lock)
        locker.unlock()

        with open(self.filename) as fh:
            content = fh.read()

        self.assertEqual(test_content, content)
