# coding: utf-8

import shutil
import tempfile
import unittest

from tionix_client.functional.report import Report
from tionix_client.functional.writers import get_writers, VersionedFileWriter


class ReportTestCase(unittest.TestCase):
    """Case for testing VersionedReport"""
    def setUp(self):
        self.temp_dir = tempfile.mkdtemp()
        self.writers = get_writers(
            save_to_file=True, file_dir=self.temp_dir, username='test')
        for writer in self.writers:
            if isinstance(writer, VersionedFileWriter):
                self.latest = writer.latest_path
                break

    def tearDown(self):
        shutil.rmtree(self.temp_dir)

    def test_report_with_file_writer(self):
        message = u'test message'
        with Report(writers=self.writers) as report:
            report.write(message)
        with open(self.latest) as fh:
            content = fh.read()
        self.assertIn(message, content)

    def test_report_with_invalid_writer(self):
        writers = [None]
        self.assertRaises(AssertionError, Report, writers=writers)
