# coding: utf-8

import os
import shutil
import StringIO
import tempfile
import unittest

from tionix_client.functional.constants import (
    REPORT_NAME, REPORT_POSTFIX_LATEST)
from tionix_client.functional.writers import (
    VersionedFileWriter, SocketWriter)


class VersionedFileTestCase(unittest.TestCase):
    """Case for testing VersionedReport"""
    def setUp(self):
        self.temp_dir = tempfile.mkdtemp()

    def tearDown(self):
        shutil.rmtree(self.temp_dir)

    def test_report(self):
        report_dir = self.temp_dir
        kwargs = dict(
            file_dir=report_dir,
            file_name=REPORT_NAME,
            latest_ext=REPORT_POSTFIX_LATEST,
            username=u'test'
        )

        file_writer = VersionedFileWriter(**kwargs)
        file_writer.init_writer()
        self.assertTrue(os.path.isfile(file_writer.latest_path))
        file_writer.close_writer()

        file_writer = VersionedFileWriter(**kwargs)
        new_version_file = file_writer.new_version
        self.assertTrue(new_version_file.endswith(u'.1'))
        file_writer.init_writer()
        file_writer.close_writer()
        self.assertTrue(os.path.isfile(new_version_file))

        file_writer = VersionedFileWriter(**kwargs)
        new_version_file = file_writer.new_version
        self.assertTrue(new_version_file.endswith(u'.2'))
        file_writer.init_writer()
        file_writer.close_writer()
        self.assertTrue(os.path.isfile(new_version_file))


class FakeSocket(object):
    def __init__(self):
        self.socket = StringIO.StringIO()

    def send_chunk(self, message):
        self.socket.write(message)

    def get_content(self):
        self.socket.seek(0)
        return self.socket.read()


class SocketWriterTestCase(unittest.TestCase):
    def setUp(self):
        self.socket = FakeSocket()

    def test_socket_writer(self):
        socket_writer = SocketWriter(socket=self.socket)
        test_message = u'test message'
        socket_writer.write(test_message)
        content = self.socket.get_content()
        self.assertIn(test_message, content)
