# coding: utf-8

from novaclient import base


class ZabbixAuthManager(base.Manager):

    alias = 'tnx-zabbix'

    def setup_monitoring(self, project_id, zabbix_user_login,
                         zabbix_user_password):
        """
        POST action to configure Zabbix monitoring
        """
        action = 'setup_monitoring'
        url = '/{0}/{1}'.format(self.alias, action)
        body = {
            action: {
                "project_id": project_id,
                "zabbix_user_login": zabbix_user_login,
                "zabbix_user_password": zabbix_user_password,
            }
        }
        return self.api.client.post(url, body=body)

    # noinspection PyUnusedLocal
    def get_templates(self, project_id):
        """
        GET action to get tempates available for project
        """
        action = 'get_templates'
        url = '/{0}/{1}?project_id={2}'.format(self.alias, action, project_id)
        _resp, body = self.api.client.get(url)
        return body['templates']

    def create_host(self, instance_id, templates):
        action = 'create_host'
        url = '/{0}/{1}'.format(self.alias, action)
        body = {
            action: {
                "instance_id": instance_id,
                "templates": templates,
            }
        }
        return self.api.client.post(url, body=body)

    def update_host(self, instance_id, templates):
        action = 'update_host'
        url = '/{0}/{1}'.format(self.alias, action)
        body = {
            action: {
                "instance_id": instance_id,
                "templates": templates,
            }
        }
        return self.api.client.post(url, body=body)

    def get_host(self, instance_id):
        action = 'get_host'
        url = '/{0}/{1}?instance_id={2}'.format(self.alias,
                                                action,
                                                instance_id)
        _resp, body = self.api.client.get(url)
        return body['host']

    def delete_host(self, instance_id):
        action = 'delete_host'
        url = '/{0}/{1}'.format(self.alias, action)
        body = {
            action: {
                "instance_id": instance_id,
            }
        }
        return self.api.client.post(url, body=body)


class ZabbixClientExtension(object):
    name = 'tnx_zabbix'
    manager_class = ZabbixAuthManager
